@@ -50,17 +50,30 @@ Generic cart class for L<Interchange6>.
 
 Cart id can be used for subclasses, e.g. primary key value for carts in the database.
 
+=over
+
+=item Writer: C<set_id>
+
+=back
+
 =cut
 
 has id => (
-    is  => 'rw',
-    isa => Str,
+    is     => 'ro',
+    isa    => Str,
+    writer => 'set_id',
 );
 
 =head2 name
 
 The cart name. Default is 'main'.
 
+=over
+
+=item Writer: C<rename>
+
+=back
+
 =cut
 
 has name => (
@@ -99,6 +112,12 @@ has products => (
 
 The session ID for the cart.
 
+=over
+
+=item Writer: C<set_sessions_id>
+
+=back
+
 =cut
 
 has sessions_id => (
@@ -153,6 +172,12 @@ sub _build_total {
 
 The user id of the logged in user.
 
+=over
+
+=item Writer: C<set_users_id>
+
+=back
+
 =cut
 
 has users_id => (
@@ -297,7 +322,7 @@ sub add {
 
         # a new product for this cart
 
-        $product->cart( $self );
+        $product->set_cart( $self );
         $self->_product_push($product);
     }
 
@@ -418,10 +443,6 @@ sub seed {
     return $self->products;
 }
 
-=head2 set_sessions_id
-
-Writer method for L<sessions_id>.
-
 =head2 update
 
 Update quantity of products in the cart.
